@@ -155,6 +155,31 @@ class Confluence(AtlassianRestAPI):
             params['limit'] = int(limit)
         return self.get(url, params=params)
 
+    def get_page_comments(self, content_id, expand=None, parent_version=None, start=0, limit=25, location=None,
+                          depth=None):
+        """
+
+        :param content_id:
+        :param expand: extensions.inlineProperties,extensions.resolution
+        :param parent_version:
+        :param start:
+        :param limit:
+        :param location: inline or not
+        :param depth:
+        :return:
+        """
+        params = {'id': content_id, 'start': start, 'limit': limit}
+        if expand:
+            params['expand'] = expand
+        if parent_version:
+            params['parentVersion'] = parent_version
+        if location:
+            params['location'] = location
+        if depth:
+            params['depth'] = depth
+        url = 'rest/api/content/{id}/child/comment'.format(id=content_id)
+        return self.get(url, params=params)
+
     def get_draft_page_by_id(self, page_id, status='draft'):
         """
         Provide content by id with status = draft
@@ -290,6 +315,14 @@ class Confluence(AtlassianRestAPI):
         """
         return self.remove_page(page_id=page_id, status='draft')
 
+    def remove_content(self, content_id):
+        """
+        Remove any content
+        :param content_id:
+        :return:
+        """
+        return self.delete('rest/api/content/{}'.format(content_id))
+
     def remove_page(self, page_id, status=None, recursive=False):
         """
         This method removes a page, if it has recursive flag, method removes including child pages
@@ -375,12 +408,14 @@ class Confluence(AtlassianRestAPI):
         page_id = self.get_page_id(space=space, title=title) if page_id is None else page_id
         type = 'attachment'
         if page_id is not None:
+            # get base name of the file to get the attachment from confluence.
+            file_base_name = os.path.basename(filename)
             extension = os.path.splitext(filename)[-1]
             content_type = self.content_types.get(extension, "application/binary")
             comment = comment if comment else "Uploaded {filename}.".format(filename=filename)
             data = {
                 'type': type,
-                "fileName": filename,
+                "fileName": file_base_name,
                 "contentType": content_type,
                 "comment": comment,
                 "minorEdit": "true"}
@@ -388,15 +423,13 @@ class Confluence(AtlassianRestAPI):
                 'X-Atlassian-Token': 'nocheck',
                 'Accept': 'application/json'}
             path = 'rest/api/content/{page_id}/child/attachment'.format(page_id=page_id)
-            # get base name of the file to get the attachment from confluence.
-            file_base_name = os.path.basename(filename)
             # Check if there is already a file with the same name
             attachments = self.get(path=path, headers=headers, params={'filename': file_base_name})
             if attachments['size']:
                 path = path + '/' + attachments['results'][0]['id'] + '/data'
             with open(filename, 'rb') as infile:
                 return self.post(path=path, data=data, headers=headers,
-                                 files={'file': (filename, infile, content_type)})
+                                 files={'file': (file_base_name, infile, content_type)})
         else:
             log.warning("No 'page_id' found, not uploading attachments")
             return None
@@ -488,6 +521,18 @@ class Confluence(AtlassianRestAPI):
                 'name': label}
         return self.post(path=url, data=data)
 
+    def remove_page_label(self, page_id, label):
+        """
+        Delete Confluence page label
+        :param page_id: content_id format
+        :param label: label name
+        :return:
+        """
+        url = 'rest/api/content/{page_id}/label'.format(page_id=page_id)
+        params = {'id': page_id,
+                  'name': label}
+        return self.delete(path=url, params=params)
+
     def history(self, page_id):
         url = 'rest/api/content/{0}/history'.format(page_id)
         return self.get(url)
@@ -1022,7 +1067,7 @@ class Confluence(AtlassianRestAPI):
         url = 'rest/plugins/1.0/{}-key'.format(plugin_key)
         return self.delete(url)
 
-    def check_long_tasks_result(self, start, limit, expand):
+    def check_long_tasks_result(self, start=None, limit=None, expand=None):
         """
         Get result of long tasks
         :param start: OPTIONAL: The start point of the collection to return. Default: None (0).
@@ -1040,7 +1085,7 @@ class Confluence(AtlassianRestAPI):
             params['limit'] = limit
         return self.get('rest/api/longtask', params=params)
 
-    def check_long_task_result(self, task_id, expand):
+    def check_long_task_result(self, task_id, expand=None):
         """
         Get result of long tasks
         :param task_id: task id
@@ -1099,3 +1144,27 @@ class Confluence(AtlassianRestAPI):
             return None
 
         return download_url
+
+    def audit(self, start_date=None, end_date=None, start=None, limit=None, search_string=None):
+        """
+        Fetch a paginated list of AuditRecord instances dating back to a certain time
+        :param start_date:
+        :param end_date:
+        :param start:
+        :param limit:
+        :param search_string:
+        :return:
+        """
+        url = 'rest/api/audit'
+        params = {}
+        if start_date:
+            params['startDate'] = start_date
+        if end_date:
+            params['endDate'] = end_date
+        if start:
+            params['start'] = start
+        if limit:
+            params['limit'] = limit
+        if search_string:
+            params['searchString'] = search_string
+        return self.get(url, params=params)
