@@ -526,6 +526,10 @@ class Jira(AtlassianRestAPI):
         issue = self.get('rest/api/2/issue/{0}?fields={1}'.format(key, field))
         return issue['fields'][field]
 
+    def issue_fields(self, key):
+        issue = self.get('rest/api/2/issue/{0}'.format(key))
+        return issue['fields']
+
     def update_issue_field(self, key, fields='*all'):
         return self.put('rest/api/2/issue/{0}'.format(key), data={'fields': fields})
 
@@ -1072,6 +1076,53 @@ class Jira(AtlassianRestAPI):
         url = 'rest/api/2/issueLinkType/{issueLinkTypeId}'.format(issueLinkTypeId=issue_link_type_id)
         return self.put(url, data=data)
 
+    def create_issue_link(self, data):
+        """
+        Creates an issue link between two issues.
+        The user requires the link issue permission for the issue which will be linked to another issue.
+        The specified link type in the request is used to create the link and will create a link from
+        the first issue to the second issue using the outward description. It also create a link from
+        the second issue to the first issue using the inward description of the issue link type.
+        It will add the supplied comment to the first issue. The comment can have a restriction who can view it.
+        If group is specified, only users of this group can view this comment, if roleLevel is specified only users
+        who have the specified role can view this comment.
+        The user who creates the issue link needs to belong to the specified group or have the specified role.
+        :param data: i.e.
+        {
+            "type": {"name": "Duplicate" },
+            "inwardIssue": { "key": "HSP-1"},
+            "outwardIssue": {"key": "MKY-1"},
+            "comment": { "body": "Linked related issue!",
+                         "visibility": { "type": "group", "value": "jira-software-users" }
+            }
+        }
+        :return:
+        """
+        log.info(
+            'Linking issue {inward} and {outward}'.format(inward=data['inwardIssue'], outward=data['outwardIssue']))
+        url = 'rest/api/2/issueLink'
+        return self.post(url, data=data)
+
+    def remove_issue_link(self, link_id):
+        """
+        Deletes an issue link with the specified id.
+        To be able to delete an issue link you must be able to view both issues
+        and must have the link issue permission for at least one of the issues.
+        :param link_id: the issue link id.
+        :return:
+        """
+        url = 'rest/api/2/issueLink/{}'.format(link_id)
+        return self.delete(url)
+
+    def get_issue_link(self, link_id):
+        """
+        Returns an issue link with the specified id.
+        :param link_id: the issue link id.
+        :return:
+        """
+        url = 'rest/api/2/issueLink/{}'.format(link_id)
+        return self.get(url)
+
     def create_filter(self, name, jql, description=None, favourite=False):
         """
         :param name: str
@@ -1827,7 +1878,7 @@ class Jira(AtlassianRestAPI):
             'startDate': start_date,
             'endDate': end_date})
 
-    def delete_spint(self, sprint_id):
+    def delete_sprint(self, sprint_id):
         """
         Deletes a sprint.
         Once a sprint is deleted, all issues in the sprint will be moved to the backlog.
@@ -1837,6 +1888,25 @@ class Jira(AtlassianRestAPI):
         """
         return self.delete('rest/agile/1.0/sprint/{sprintId}'.format(sprintId=sprint_id))
 
+    def update_partially_sprint(self, sprint_id, data):
+        """
+        Performs a partial update of a sprint.
+        A partial update means that fields not present in the request JSON will not be updated.
+        Notes:
+
+        Sprints that are in a closed state cannot be updated.
+        A sprint can be started by updating the state to 'active'.
+        This requires the sprint to be in the 'future' state and have a startDate and endDate set.
+        A sprint can be completed by updating the state to 'closed'.
+        This action requires the sprint to be in the 'active' state. This sets the completeDate to the time of the request.
+        Other changes to state are not allowed.
+        The completeDate field cannot be updated manually.
+        :param sprint_id:
+        :param data: { "name": "new name"}
+        :return:
+        """
+        return self.post('rest/agile/1.0/sprint/{}'.format(sprint_id), data=data)
+
     def get_sprint_issues(self, sprint_id, start, limit):
         """
         Returns all issues in a sprint, for a given sprint Id.
